import request from "@/utils/request";

// 查询常用联系人列表
export function listPeoplegroup(query) {
  return request({
    url: "/oa/group/list",
    method: "get",
    params: query,
  });
}

// 查询常用联系人详细
export function getPeoplegroup(id) {
  return request({
    url: "/oa/group/selectUserByGroup/" + id,
    method: "get",
  });
}

// 新增常用联系人
export function addPeoplegroup(data) {
  return request({
    url: "/oa/group",
    method: "post",
    data: data,
  });
}

// 修改常用联系人
export function updatePeoplegroup(data) {
  return request({
    url: "/oa/group",
    method: "put",
    data: data,
  });
}

// 删除常用联系人
export function delPeoplegroup(id) {
  return request({
    url: "/oa/group/" + id,
    method: "delete",
  });
}
//确认常用联系人
export function addPeople(data) {
  return request({
    url: "/oa/contacts",
    method: "post",
    data: data,
  });
}
